@@ -1,9 +1,10 @@
 // SPDX-FileCopyrightText: 2021 Linus Jahn <lnj@kaidan.im>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "invidiousapi.h"
 
+#include <KLocalizedString>
+
 #include <QJsonDocument>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
@@ -11,8 +12,6 @@
 #include <QUrl>
 #include <QUrlQuery>
 
-#include <KLocalizedString>
-
 const QString API_FEED = QStringLiteral("/api/v1/auth/feed");
 const QString API_LOGIN = QStringLiteral("/login");
 const QString API_SEARCH = QStringLiteral("/api/v1/search");
@@ -36,6 +35,18 @@ InvidiousApi::InvidiousApi(QNetworkAccessManager *netManager, QObject *parent)
 {
 }
 
+bool InvidiousApi::supportsFeature(AbstractApi::SupportedFeature feature)
+{
+    switch (feature) {
+    case PopularPage:
+        return true;
+    case TrendingCategories:
+        return true;
+    }
+
+    return false;
+}
+
 QFuture<LogInResult> InvidiousApi::logIn(QStringView username, QStringView password)
 {
     QUrlQuery params;
@@ -81,9 +92,26 @@ QString InvidiousApi::resolveVideoUrl(QStringView videoId)
     return QStringLiteral("ytdl://%1").arg(videoId);
 }
 
-QFuture<VideoListResult> InvidiousApi::requestSearchResults(const SearchParameters &parameters)
+QFuture<SearchListResult> InvidiousApi::requestSearchResults(const SearchParameters &parameters)
 {
-    return requestVideoList(Search, QStringLiteral(""), parameters.toQueryParameters());
+    auto url = videoListUrl(Search, QStringLiteral(""), parameters.toQueryParameters());
+    auto request = QNetworkRequest(url);
+
+    return get<SearchListResult>(std::move(request), [=](QNetworkReply *reply) -> SearchListResult {
+        if (auto doc = QJsonDocument::fromJson(reply->readAll()); !doc.isNull()) {
+            const auto obj = doc.object();
+
+            QList<SearchResult> results;
+            for (auto value : doc.array()) {
+                if (value.isObject()) {
+                    results << SearchResult::fromJson(value.toObject());
+                }
+            }
+
+            return results;
+        }
+        return invalidJsonError();
+    });
 }
 
 QFuture<VideoListResult> InvidiousApi::requestFeed(qint32 page)
@@ -328,9 +356,6 @@ QFuture<VideoListResult> InvidiousApi::requestVideoList(VideoListType queryType,
 
                 // add videos marked as notification
                 auto results = VideoBasicInfo::fromJson(obj.value("notifications"_L1).toArray());
-                for (auto &video : results) {
-                    video.setIsNotification(true);
-                }
 
                 // add the rest
                 results << VideoBasicInfo::fromJson(obj.value("videos"_L1).toArray());
