@@ -1,17 +1,17 @@
 // SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
-#include <QObject>
-#include <QQmlEngine>
-#include <QtQml/qqmlregistration.h>
-#include <optional>
-
 #include "sourcemanager.h"
 #include "videocontroller.h"
 
+#include <QObject>
+#include <QQmlEngine>
+#include <QtQml>
+
+#include <optional>
+
 class PlasmaTube : public QObject
 {
     Q_OBJECT
