@@ -8,13 +8,14 @@
 #include "models/videolistmodel.h"
 #include "models/videomodel.h"
 
-#include <clocale>
-
+#ifdef Q_OS_ANDROID
+#include <QGuiApplication>
+#else
 #include <QApplication>
+#endif
 #include <QCommandLineParser>
 #include <QIcon>
 #include <QQmlApplicationEngine>
-#include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
 
@@ -28,7 +29,6 @@
 #endif
 
 #include "controllers/windowcontroller.h"
-#include "models/playlistsmodel.h"
 #include "plasmatube-version.h"
 
 std::optional<QString> parseVideoString(const QString &vid)
@@ -44,11 +44,15 @@ std::optional<QString> parseVideoString(const QString &vid)
 
 int main(int argc, char **argv)
 {
+#ifdef Q_OS_ANDROID
+    QGuiApplication app(argc, argv);
+#else
     QApplication app(argc, argv);
 
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE") && QQuickStyle::name().isEmpty()) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
+#endif
 
     KLocalizedString::setApplicationDomain("plasmatube");
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
@@ -67,10 +71,6 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(about);
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.plasmatube")));
 
-    // Qt sets the locale in the QGuiApplication constructor, but libmpv
-    // requires the LC_NUMERIC category to be set to "C", so change it back.
-    setlocale(LC_NUMERIC, "C");
-
     QQmlApplicationEngine engine;
 
 #ifdef HAVE_KDBUSADDONS
@@ -107,6 +107,8 @@ int main(int argc, char **argv)
     qmlRegisterSingletonInstance<PlasmaTubeSettings>("org.kde.plasmatube.private", 1, 0, "Settings", &settings);
     QObject::connect(&app, &QCoreApplication::aboutToQuit, &settings, &PlasmaTubeSettings::save);
 
+    qmlRegisterType<MpvObject>("org.kde.plasmatube.private", 1, 0, "MpvObject");
+
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("YouTube client"));
 
@@ -121,7 +123,7 @@ int main(int argc, char **argv)
     if (engine.rootObjects().isEmpty())
         return -1;
 
-    if (QApplication::arguments().length() > 1) {
+    if (QCoreApplication::arguments().length() > 1) {
         if (const auto videoUrl = parseVideoString(app.arguments()[1])) {
             PlasmaTube::instance().openVideo(*videoUrl);
         }
